@@ -29,7 +29,6 @@
 
 #define SLEEP_TIMEOUT   180     // Animation sleeps after SLEEP_TIMEOUT seconds
                                 // of mouse inactivity.
-#define BUBBLE_TIMEOUT  4000    // Minimum milliseconds to display a tip
 #define TIPS_FILE       "tips"  // Display tips in TIP_FILE-LANG, e.g "tips-en"
 #define TIP_FREQUENCY   20      // Frequency tips are displayed small == more
                                 // often.
@@ -47,7 +46,7 @@
 //
 // Constructor
 //
-Amor::Amor() : QObject()
+Amor::Amor() : QObject(), DCOPObject( "AmorIface" )
 {
     mAmor = 0;
     mBubble = 0;
@@ -83,9 +82,6 @@ Amor::Amor() : QObject()
         mStackTimer = new QTimer(this);
         connect(mStackTimer, SIGNAL(timeout()), SLOT(restack()));
 
-        mBubbleTimer = new QTimer(this);
-        connect(mBubbleTimer, SIGNAL(timeout()), SLOT(hideBubble()));
-
         time(&mActiveTime);
         mCursPos = QCursor::pos();
         mCursorTimer = new QTimer(this);
@@ -116,6 +112,19 @@ Amor::~Amor()
     delete mBubble;
 }
 
+//---------------------------------------------------------------------------
+//
+void Amor::showTip( QString tip )
+{
+    if ( mConfig.mAppTips )
+    {
+	if ( mCurrAnim == mBaseAnim || mCurrAnim->frameNum() == 0 )
+	    showBubble( tip );
+	else
+	    mTipText = tip;
+    }
+}
+
 //---------------------------------------------------------------------------
 //
 // Clear existing theme and reload configuration
@@ -151,8 +160,6 @@ bool Amor::readConfig()
     // Read user preferences
     mConfig.read();
 
-//    mConfig.mOnTop = true;       // XXX until normal mode is fixed
-
     if (mConfig.mTips)
     {
         mTips.setFile(TIPS_FILE);
@@ -200,8 +207,6 @@ void Amor::showBubble(const QString& msg)
         mBubble->setOrigin(mAmor->x()+mAmor->width()/2,
                            mAmor->y()+mAmor->height()/2);
         mBubble->setMessage(msg);
-        mBubble->show();
-        mBubbleTimer->start(BUBBLE_TIMEOUT + msg.length() * 30, TRUE);
     }
 }
 
@@ -239,8 +244,6 @@ void Amor::selectAnimation(State state)
             mTargetWin = mNextTarget;
             if (mTargetWin != None)
             {
-//                mTargetRect = windowGeometry(mTargetWin);
-//                mTargetRect = KWM::geometry(mTargetWin, true);
                 mTargetRect = KWin::info(mTargetWin).frameGeometry;
                 if (mCurrAnim->frame())
                 {
@@ -284,7 +287,7 @@ void Amor::selectAnimation(State state)
             // is not the base, otherwise select the base.  This makes us
             // alternate between the base animation and a random
             // animination.
-            if (mCurrAnim == mBaseAnim && !mBubble)
+            if (mCurrAnim == mBaseAnim && (!mBubble || !mBubble->isVisible() ) )
             {
                 mCurrAnim = mTheme.random(ANIM_NORMAL);
             }
@@ -455,7 +458,13 @@ void Amor::slotTimeout()
     // a helpful tip.
     if (mCurrAnim == mBaseAnim && mCurrAnim->frameNum() == 0)
     {
-        if (kapp->random()%TIP_FREQUENCY == 1 && mConfig.mTips && !mBubble)
+	if ( !mTipText.isEmpty() && mConfig.mAppTips )
+	{
+	    showBubble( mTipText );
+	    mTipText = QString();
+	}
+	else if (kapp->random()%TIP_FREQUENCY == 1 && mConfig.mTips &&
+		( !mBubble || !mBubble->isVisible() ) )
         {
             showBubble(mTips.tip());
         }
@@ -465,7 +474,10 @@ void Amor::slotTimeout()
 
     if (!mCurrAnim->next())
     {
-        selectAnimation(mState);
+	if ( mBubble && mBubble->isVisible() )
+	    mCurrAnim->reset();
+	else
+	    selectAnimation(mState);
     }
 }
 
