@@ -9,14 +9,20 @@
 #include <amorbubble.moc>
 #include <qbitmap.h>
 #include <qpainter.h>
+#include <qtextbrowser.h>
+#include <qtooltip.h>
 #include <kapp.h>
+#include <kstddirs.h>
+#include <kdebug.h>
+#include <klocale.h>
 #include <X11/Xlib.h>
 #include <X11/extensions/shape.h>
 
-#define ARROW_WIDTH     8
-#define ARROW_HEIGHT    10
+#define ARROW_WIDTH     10
+#define ARROW_HEIGHT    12
 #define BORDER_SIZE     4
 #define BUBBLE_OFFSET   16
+#define BUBBLE_TIMEOUT  4000    // Minimum milliseconds to display a tip
 
 //---------------------------------------------------------------------------
 //
@@ -27,6 +33,22 @@ AmorBubble::AmorBubble()
 {
     mOriginX = 0;
     mOriginY = 0;
+    mBrowser = new QTextBrowser( this );
+    mBrowser->setFrameStyle( QFrame::NoFrame | QFrame::Plain );
+    mBrowser->setMargin( 0 );
+    mBrowser->setPaper( QToolTip::palette().active().brush( QColorGroup::Background ) );
+    mBrowser->setVScrollBarMode( QTextBrowser::AlwaysOff );
+    mBrowser->setHScrollBarMode( QTextBrowser::AlwaysOff );
+    mBrowser->viewport()->installEventFilter( this );
+
+    mBrowser->mimeSourceFactory()->addFilePath(KGlobal::dirs()->findResourceDir("data", "kdewizard/pics")+"kdewizard/pics/");
+    QStringList icons = KGlobal::dirs()->resourceDirs("icon");
+    QStringList::Iterator it;
+    for (it = icons.begin(); it != icons.end(); ++it)
+	mBrowser->mimeSourceFactory()->addFilePath(*it);
+
+    mBubbleTimer = new QTimer(this);
+    connect(mBubbleTimer, SIGNAL(timeout()), SLOT(hide()));
 }
 
 //---------------------------------------------------------------------------
@@ -44,8 +66,14 @@ AmorBubble::~AmorBubble()
 //
 void AmorBubble::setMessage(const QString& message)
 {
-    mMessage = message;
+    mMessage = QString( "<html>%1</html>" ).arg( message );
+    // hacks because heightForWidth() doesn't work.
+    setGeometry( -1000, 0, 300, 1000 );
+    show();
+    mBrowser->setGeometry( 0, 0, 250, 1000 );
+    mBrowser->setText( mMessage );
     calcGeometry();
+    mBubbleTimer->start(BUBBLE_TIMEOUT + message.length() * 30, TRUE);
 }
 
 //---------------------------------------------------------------------------
@@ -54,15 +82,13 @@ void AmorBubble::setMessage(const QString& message)
 //
 void AmorBubble::calcGeometry()
 {
-    QPainter painter(this);
-    mBound = painter.boundingRect(0, 0, 200, 400, WordBreak, mMessage);
-
-    // enforce minimum size
-    mBound = mBound.unite(QRect(0, 0, 80, 20));
+    mBound = QRect( 0, 0, 250, 0 );
+//    mBound.setHeight( mBrowser->heightForWidth( mBound.width() ) );
+    mBound.setHeight( mBrowser->contentsHeight() );
     mBound.moveBy(ARROW_WIDTH+BORDER_SIZE, BORDER_SIZE);
 
     // initialise the default geometry of the bubble
-    int w = mBound.width() + BORDER_SIZE * 2 + ARROW_WIDTH * 2;
+    int w = mBound.width() + BORDER_SIZE * 2 + ARROW_WIDTH;
     int h = mBound.height() + BORDER_SIZE * 2;
     int xpos = mOriginX + BUBBLE_OFFSET;
     int ypos = mOriginY - BORDER_SIZE - ARROW_HEIGHT / 2;
@@ -77,6 +103,7 @@ void AmorBubble::calcGeometry()
         // source on right
         xpos = mOriginX - w - BUBBLE_OFFSET;
         mArrowHorz = Right;
+	mBound.moveBy( -ARROW_WIDTH, 0 );
     }
 
     if (mOriginY + h > kapp->desktop()->height())
@@ -87,6 +114,7 @@ void AmorBubble::calcGeometry()
     }
 
     setGeometry(xpos, ypos, w, h);
+    mBrowser->setGeometry( mBound );
 
     // create and apply the shape mask
     mMask.resize(w, h);
@@ -108,18 +136,21 @@ void AmorBubble::drawBubble(QPainter &p)
 {
     QPointArray pointArray(3);
 
+    int left = ARROW_WIDTH;
+
     if (mArrowHorz == Left)
     {
-        pointArray.setPoint(0, ARROW_WIDTH, 0);
-        pointArray.setPoint(1, 0, -2);
-        pointArray.setPoint(2, ARROW_WIDTH, ARROW_HEIGHT);
+        pointArray.setPoint(0, ARROW_WIDTH+1, 0);
+        pointArray.setPoint(1, 0, -3);
+        pointArray.setPoint(2, ARROW_WIDTH+1, ARROW_HEIGHT);
     }
     else
     {
         pointArray.setPoint(0, 0, 0);
-        pointArray.setPoint(1, ARROW_WIDTH, -2);
+        pointArray.setPoint(1, ARROW_WIDTH+1, -3);
         pointArray.setPoint(2, 0, ARROW_HEIGHT);
         pointArray.translate(width() - ARROW_WIDTH - 1, 0);
+	left = 0;
     }
 
     if (mArrowVert == Top)
@@ -131,14 +162,14 @@ void AmorBubble::drawBubble(QPainter &p)
         pointArray.translate(0, height() - BORDER_SIZE - ARROW_HEIGHT / 2);
     }
 
-    p.drawRoundRect(ARROW_WIDTH, 0, width() - ARROW_WIDTH*2, height(), 20, 20);
+    p.drawRoundRect(left, 0, width() - ARROW_WIDTH, height(), 10, 20);
 
     QPen pen(p.pen());
     p.setPen(NoPen);
     p.drawPolygon(pointArray);
 
     p.setPen(pen);
-    p.drawPolyline(pointArray);
+    p.drawPolyline(pointArray, 0, 3);
 }
 
 //---------------------------------------------------------------------------
@@ -149,9 +180,8 @@ void AmorBubble::paintEvent(QPaintEvent *)
 {
     QPainter painter(this);
     painter.setPen(black);
-    painter.setBrush(yellow);
+    painter.setBrush( QToolTip::palette().active().brush( QColorGroup::Background ) );
     drawBubble(painter);
-    painter.drawText(mBound, AlignVCenter | WordBreak, mMessage);
 }
 
 //---------------------------------------------------------------------------
@@ -163,3 +193,25 @@ void AmorBubble::mouseReleaseEvent(QMouseEvent *)
     hide();
 }
 
+//---------------------------------------------------------------------------
+//
+bool AmorBubble::eventFilter( QObject *, QEvent *e )
+{
+    switch ( e->type() )
+    {
+	case QEvent::Enter:
+	    mBubbleTimer->stop();
+	    break;
+	case QEvent::Leave:
+	    if ( isVisible() )
+		mBubbleTimer->start( 1000, true );
+	    break;
+	case QEvent::MouseButtonRelease:
+	    hide();
+	    break;
+	default:
+	    break;
+    }
+
+    return false;
+}
