@@ -5,8 +5,8 @@
 #include "kinputline.moc"
 
 
-KInputLine::KInputLine(QWidget *parent, QString text, QString init) 
-  : QDialog(parent,"",TRUE)
+KInputLine::KInputLine(QWidget *parent, const QString & text, const QString & init) 
+  : QDialog(parent, 0, TRUE)
 {
   int width = 200;
 
