@@ -14,17 +14,15 @@ class KInputLine : public QDialog
   
 public:
 
-  KInputLine(QWidget *parent=0, QString text="", QString init="");
+  KInputLine(QWidget *parent=0, const QString & text = QString::null, const QString & init = QString::null);
   ~KInputLine() {};
 
-  const char* getText() { return lineedit->text(); };
+  QString getText() { return lineedit->text(); };
   
 private:
-
   QLabel *label;
   QLineEdit *lineedit;
   QPushButton *ok, *cancel;          
 };
 
-
 #endif
