@@ -1,4 +1,5 @@
 #include <stdio.h>
+#include <stdlib.h>
 
 #include <qapplication.h>
 #include <qpushbutton.h>
@@ -18,7 +19,7 @@ void dumpMap()
 {
   // guess some default parameters
   QSize   mapSize(kapp->desktop()->size());
-  
+
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
   QCString mapName = args->getOption("map");
@@ -29,7 +30,7 @@ void dumpMap()
     {
       int w,h;
       if (sscanf(ssize.data(), "%dx%d", &w, &h) == 2)
-	mapSize = QSize(w,h);
+        mapSize = QSize(w,h);
     }
 
   kdDebug() << "map=" << mapName << " out=" << outName << " size=" << mapSize.width() << "x" << mapSize.height() << endl;
@@ -52,20 +53,20 @@ static KCmdLineOptions options[] =
   { "o <file>", I18N_NOOP("The name of the file to write to"), "dump.ppm" },
   { "size <WxH>", I18N_NOOP("The size of the map to dump"), 0 },
   { 0, 0, 0 }
-};    
-      
+};
+
 int main( int argc, char **argv )
 {
   KAboutData aboutData("kworldwatch", I18N_NOOP("KWorldWatch"),
     version, description, KAboutData::License_GPL,
     "(c) 1998-2000, Matthias Hoelzer-Kluepfel");
-  aboutData.addAuthor("Matthias Hoelzer-Kluepfel",0, "mhk@caldera.de");
+  aboutData.addAuthor("Matthias Hoelzer-Kluepfel",0, "hoelzer@kde.org");
 
   KCmdLineArgs::init( argc, argv, &aboutData );
   KCmdLineArgs::addCmdLineOptions(options);
 
   KApplication app;
-  
+
   KImageIO::registerFormats();
 
   // dump mode, used for background drawing
@@ -81,12 +82,12 @@ int main( int argc, char **argv )
   if (kapp->isRestored())
     RESTORE(TopLevel)
   else
-    {    
+    {
       toplevel = new TopLevel();
       toplevel->setCaption(i18n("KDE World Wide Watch"));
 
       app.setMainWidget(toplevel);
     }
-	
+
   return app.exec();
 }
