@@ -11,18 +11,18 @@
 
 
 TopLevel::TopLevel ()
-  : KTMainWindow()
+  : KMainWindow(0)
 {
   world = new World(this);
 
   setupStatusBar();
 
-  setView(world);
+  setCentralWidget(world);
 
   startTimer(1000); 
   timerEvent(NULL);
 
-  setFixedSize(world->width(), world->height()+statusbar->height());
+  setFixedSize(minimumSize());
 
   show();
 }
@@ -30,15 +30,12 @@ TopLevel::TopLevel ()
 
 TopLevel::~TopLevel ()
 {
-  delete statusbar;
 }
 
 
 void TopLevel::setupStatusBar()
 {
-  statusbar = new KStatusBar(this);
-  statusbar->insertItem("", ID_LOCALTIME);
-  setStatusBar(statusbar);
+  statusBar()->insertItem("", ID_LOCALTIME, 1);
 }  
 
 
@@ -58,7 +55,7 @@ void TopLevel::timerEvent(QTimerEvent *)
            .arg(KGlobal::locale()->formatDate(dattim1.date(), true))
            .arg(KGlobal::locale()->formatTime(dattim1.time(), true));
 
-  statusbar->changeItem(buffer + " " + buffer1, ID_LOCALTIME);
+  statusBar()->changeItem(buffer + " " + buffer1, ID_LOCALTIME);
 
   world->setTime();
 }
