@@ -93,6 +93,7 @@
 #endif
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <math.h>
 #include <ctype.h>
 #include <time.h>
@@ -100,11 +101,10 @@
 
 #include <qkeycode.h>
 #include <qtooltip.h>
-#include <qmessagebox.h>
 
 #include <kapp.h>
 #include <kconfig.h>
-#include <kwm.h>
+#include <kwin.h>
 #include <ktmainwindow.h>
 #include <ktoolbar.h>
 #include <kiconloader.h>
@@ -112,6 +112,7 @@
 #include <klocale.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
+#include <kmessagebox.h>
 
 #include "kodo.h"
 
@@ -474,10 +475,10 @@ void Kodometer::refresh(void)
 	trip_s ="------";
     }
 
-    double d=atof(distance_s);
+    double d=distance_s.toDouble();
     totalLabel->setValue(d);
 
-    d=atof(trip_s);
+    d=trip_s.toDouble();
     tripLabel->setValue(d);
 
 }
@@ -787,12 +788,13 @@ void Kodometer::help()
 
 void Kodometer::about()
 {
-    QMessageBox::about( this, i18n("About Mouspedometa"),
+    KMessageBox::about( this, 
 			i18n("Mouspedometa measures your desktop mileage.\n"
 			     "Copyright 1998 Armen Nakashian\n\n"
 			     "This program is free, do with it what you will.\n"
 			     "This program is part of the K Desktop Environment.\n\n"
-			     "http://yawara.anime.net/kodo/\n\n"));
+			     "http://yawara.anime.net/kodo/\n\n"),
+			i18n("About Mouspedometa"));
 }
 
 static const char* description=I18N_NOOP("Mouspedometa measures your desktop mileage");
@@ -813,7 +815,9 @@ int main(int argc,char **argv)
     Kodometer o(0,"Kodo");
 
     // Get rid of the title bar.
-    KWM::setDecoration(o.winId(),KWM::tinyDecoration);
+    //KWM::setDecoration(o.winId(),KWM::tinyDecoration);
+    KWin::setType(o.winId(), NET::Dock); // note that this makes it sticky as well...
+    // Maybe use NET::Toolbar or something else
     a.setMainWidget(&o);
     a.setTopWidget(&o);
 
